@@ -1,5 +1,5 @@
 #
-# $Id: Https.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Https.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # audit::https Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable https audit ssl openssl) ],
       attributes => {
          uri => [ qw(uri) ],
@@ -51,7 +51,7 @@ sub check_ssl3_support {
       return $self->log->error("check_ssl3_support: uri [$uri] invalid format");
    }
 
-   my $string_uri = Metabrik::String::Uri->new_from_brik($self);
+   my $string_uri = Metabrik::String::Uri->new_from_brik($self) or return;
 
    my $hash = $string_uri->parse($uri)
       or return $self->log->error("check_ssl3_support: parse failed");
