@@ -1,5 +1,5 @@
 #
-# $Id: Rsync.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id$
 #
 # client::rsync Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable network) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision$',
+      tags => [ qw(unstable client network rsync) ],
       commands => {
          sync => [ qw(source destination) ],
       },
@@ -43,8 +41,12 @@ sub sync {
    my $self = shift;
    my ($source, $destination) = @_;
 
-   $self->brik_help_run_undef_arg('sync', $source) or return;
-   $self->brik_help_run_undef_arg('sync', $destination) or return;
+   if (! defined($source)) {
+      return $self->log->error($self->brik_help_run('sync'));
+   }
+   if (! defined($destination)) {
+      return $self->log->error($self->brik_help_run('destination'));
+   }
 
    my $source_root = $self->source_root;
    my $destination_root = $self->destination_root;
@@ -84,7 +86,7 @@ Metabrik::Client::Rsync - client::rsync Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
