@@ -1,5 +1,5 @@
 #
-# $Id: Tcp.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Tcp.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
 #
 # client::tcp Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 508610fe2b1a $',
       tags => [ qw(unstable client tcp socket netcat) ],
       attributes => {
          host => [ qw(host) ],
@@ -25,13 +25,13 @@ sub brik_properties {
          _select => [ qw(INTERNAL) ],
       },
       attributes_default => {
-         port => 'tcp',
+         protocol => 'tcp',
          eof => 0,
          size => 1024,
          use_ipv6 => 0,
       },
       commands => {
-         connect => [ ],
+         connect => [ qw(host|OPTIONAL port|OPTIONAL) ],
          read => [ qw(size) ],
          readall => [ ],
          write => [ qw($data) ],
@@ -63,12 +63,11 @@ sub connect {
 
    $host ||= $self->host;
    $port ||= $self->port;
-
    if (! defined($host)) {
-      return $self->log->error($self->brik_help_set('host'));
+      return $self->log->error($self->brik_help_run('connect'));
    }
    if (! defined($port)) {
-      return $self->log->error($self->brik_help_set('port'));
+      return $self->log->error($self->brik_help_run('connect'));
    }
 
    my $context = $self->context;
