@@ -1,5 +1,5 @@
 #
-# $Id: Whois.pm,v 9bb393adbc03 2015/03/11 06:47:35 gomor $
+# $Id: Whois.pm,v 72b1d01de63e 2015/10/12 19:37:55 gomor $
 #
 # client::whois Brik
 #
@@ -11,15 +11,18 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 9bb393adbc03 $',
+      revision => '$Revision: 72b1d01de63e $',
       tags => [ qw(unstable client whois) ],
       commands => {
          domain => [ qw(domain) ],
          available => [ qw(domain) ],
          expire => [ qw(domain) ],
          abuse => [ qw(domain) ],
+         netname => [ qw(ip_address|$ip_address_list|hostname) ],
       },
       require_modules => {
+         'Metabrik::Client::Dns' => [ ],
+         'Metabrik::Network::Address' => [ ],
          'Metabrik::Network::Whois' => [ ],
       },
    };
@@ -173,6 +176,49 @@ sub expire {
 sub abuse {
 }
 
+sub netname {
+   my $self = shift;
+   my ($arg0) = @_;
+
+   if (! defined($arg0)) {
+      return $self->log->error($self->brik_help_run('netname'));
+   }
+
+   my $ip_list = [];
+   # If this is not an IP address list, it may be a hostname
+   # We try to resolve it.
+   my $na = Metabrik::Network::Address->new_from_brik($self) or return;
+   if (! ref($arg0) && ! $na->is_ip($arg0)) {
+      my $cd = Metabrik::Client::Dns->new_from_brik($self) or return;
+      $ip_list = $cd->a_lookup($arg0) or return;
+   }
+   else {
+      if (ref($arg0) eq 'ARRAY') {
+         $ip_list = $arg0;
+      }
+      elsif (! ref($arg0)) {
+         $ip_list = [ $arg0 ];
+      }
+   }
+
+   my $results = {};
+   my $nw = Metabrik::Network::Whois->new_from_brik($self) or return;
+   for my $ip (@$ip_list) {
+      my $lines = $nw->target($ip) or next;
+
+      my $netname = '';
+      for my $line (@$lines) {
+         if ($line =~ /netname:/i) {
+            my @toks = split(/\s+/, $line);
+            $results->{$ip} = $toks[-1];
+            last;
+         }
+      }
+   }
+
+   return $results;
+}
+
 1;
 
 __END__
