@@ -1,5 +1,5 @@
 #
-# $Id: Keystore.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Keystore.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # database::keystore Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable database keystore) ],
       attributes => {
          db => [ qw(keystore_db) ],
@@ -63,7 +63,7 @@ sub decrypt {
    my $read = $self->read($db)
       or return $self->log->error("decrypt: read failed");
 
-   my $crypto_aes = Metabrik::Crypto::Aes->new_from_brik($self);
+   my $crypto_aes = Metabrik::Crypto::Aes->new_from_brik($self) or return;
 
    my $decrypted = $crypto_aes->decrypt($read)
       or return $self->log->error("decrypt: decrypt failed");
@@ -79,7 +79,7 @@ sub encrypt {
       return $self->log->error($self->brik_help_run('encrypt'));
    }
 
-   my $crypto_aes = Metabrik::Crypto::Aes->new_from_brik($self);
+   my $crypto_aes = Metabrik::Crypto::Aes->new_from_brik($self) or return;
 
    my $encrypted = $crypto_aes->encrypt($data)
       or return $self->log->error("encrypt: encrypt failed");
