@@ -1,5 +1,5 @@
 #
-# $Id: Csv.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
+# $Id: Csv.pm,v 616178e78f07 2015/10/17 16:55:47 gomor $
 #
 # file::csv Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cb13feea4e0 $',
+      revision => '$Revision: 616178e78f07 $',
       tags => [ qw(unstable csv file) ],
       attributes => {
          input => [ qw(file) ],
@@ -32,11 +32,11 @@ sub brik_properties {
       commands => {
          read => [ qw(input_file|OPTIONAL) ],
          write => [ qw(csv_struct output_file|OPTIONAL) ],
-         get_col_by_name => [ qw($data|$READ column_name column_value) ],
-         get_col_by_number => [ qw($data|$READ integer) ],
+         get_column_values => [ qw($data column_name|column_int) ],
       },
       require_modules => {
-         'Text::CSV' => [ ],
+         'Text::CSV_XS' => [ ],
+         #'Text::CSV' => [ ],
          'Metabrik::File::Read' => [ ],
          'Metabrik::File::Write' => [ ],
       },
@@ -60,15 +60,17 @@ sub read {
 
    $input ||= $self->input;
    if (! defined($input)) {
-      return $self->log->error($self->brik_help_set('input'));
+      return $self->log->error($self->brik_help_run('read'));
    }
 
-   my $csv = Text::CSV->new({
+   my $csv = Text::CSV_XS->new({
+   #my $csv = Text::CSV->new({
       binary => 1,
       sep_char => $self->separator,
       allow_loose_quotes => 1,
       allow_loose_escapes => 1,
-   }) or return $self->log->error('read: Text::CSV new failed');
+   }) or return $self->log->error('read: Text::CSV_XS new failed');
+   #}) or return $self->log->error('read: Text::CSV new failed');
 
    my $read = Metabrik::File::Read->new_from_brik($self) or return;
    $read->encoding($self->encoding);
@@ -86,6 +88,7 @@ sub read {
             $headers = $row;
             $count = scalar @$row - 1;
             $first_line = 0;
+            $self->header($headers);
             next;
          }
 
@@ -115,10 +118,13 @@ sub write {
    my $self = shift;
    my ($csv_struct, $output) = @_;
 
-   $output ||= $self->output;
+   if (! defined($csv_struct)) {
+      return $self->log->error($self->brik_help_run('write'));
+   }
 
+   $output ||= $self->output;
    if (! defined($output)) {
-      return $self->log->error($self->brik_help_set('output'));
+      return $self->log->error($self->brik_help_run('write'));
    }
 
    # We handle handle array of hashes format (aoh) for writing
@@ -185,29 +191,44 @@ sub write {
    return $written;
 }
 
-sub get_col_by_name {
+sub get_column_values {
    my $self = shift;
-   my ($data, $type, $value) = @_;
+   my ($data, $column) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('get_col_by_name'));
-   }
-   if (! defined($type)) {
-      return $self->log->error($self->brik_help_run('get_col_by_name'));
-   }
-   if (! defined($value)) {
-      return $self->log->error($self->brik_help_run('get_col_by_name'));
+   if (! defined($data) && ! defined($column)) {
+      return $self->log->error($self->brik_help_run('get_column_values'));
    }
 
-   if (! $self->first_line_is_header || @{$self->header} == 0) {
-      return $self->log->error("get_col_by_name: no CSV header found");
+   if (ref($data) ne 'ARRAY') {
+      return $self->log->error("get_column_values: arg1 must be ARRAYREF");
    }
 
    my @results = ();
-   for my $row (@$data) {
-      if (exists($row->{$type})) {
-         if ($row->{$type} eq $value) {
-            push @results, $row;
+   # CSV structure is an ARRAYREF of HASHREFs
+   if ($self->first_line_is_header) {
+      if (@{$self->header} == 0) {
+         return $self->log->error("get_column_values: no CSV header found");
+      }
+
+      for my $row (@$data) {
+         if (ref($row) ne 'HASH') {
+            $self->log->warning("get_column_values: row is not a HASHREF");
+            next;
+         }
+         if (exists($row->{$column})) {
+            push @results, $row->{$column};
+         }
+      }
+   }
+   # CSV structure is an ARRAYREF of ARRAYREFs
+   elsif ($column =~ m{^\d+$}) {
+      for my $row (@$data) {
+         if (ref($row) ne 'ARRAY') {
+            $self->log->warning("get_column_values: row is not an ARRAYREF");
+            next;
+         }
+         if (exists($row->[$column])) {
+            push @results, $row->[$column];
          }
       }
    }
@@ -215,13 +236,6 @@ sub get_col_by_name {
    return \@results;
 }
 
-sub get_col_by_number {
-   my $self = shift;
-   my ($data, $number) = @_;
-
-   return $self->log->info("XXX: TODO");
-}
-
 1;
 
 __END__
