@@ -1,5 +1,5 @@
 #
-# $Id: Json.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Json.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # file::json Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable json file) ],
       attributes => {
          input => [ qw(file) ],
@@ -57,7 +57,7 @@ sub read {
    my $data = $self->read($input)
       or return $self->log->error("read: read failed");
 
-   my $string_json = Metabrik::String::Json->new_from_brik($self);
+   my $string_json = Metabrik::String::Json->new_from_brik($self) or return;
 
    my $json = $string_json->decode($data)
       or return $self->log->error("read: decode failed");
@@ -78,7 +78,7 @@ sub write {
       return $self->log->error($self->brik_help_set('output'));
    }
 
-   my $string_json = Metabrik::String::Json->new_from_brik($self);
+   my $string_json = Metabrik::String::Json->new_from_brik($self) or return;
 
    my $data = $string_json->encode($json_hash)
       or return $self->log->error("write: encode failed");
