@@ -1,5 +1,5 @@
 #
-# $Id: Write.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Write.pm,v 5be2a244bacc 2015/03/26 07:06:31 gomor $
 #
 # file::write Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 5be2a244bacc $',
       tags => [ qw(unstable file) ],
       attributes => {
          output => [ qw(file) ],
@@ -27,8 +27,8 @@ sub brik_properties {
          unbuffered => 0,
       },
       commands => {
-         open => [ qw(file|OPTIONAL) ],
-         write => [ qw($data|$data_ref|$data_list) ],
+         open => [ qw(file|OPTIONAL RETURN:$fd) ],
+         write => [ qw($data|$data_ref|$data_list RETURN:$data|$data_ref|$data_list) ],
          close => [ ],
       },
    };
@@ -85,6 +85,8 @@ sub open {
       select($previous_default);          
    }
 
+   $self->debug && $self->log->debug("open: fd [$out]");
+
    return $self->fd($out);
 }
 
