@@ -1,5 +1,5 @@
 #
-# $Id: Countrycode.pm,v a6e30d37450c 2015/03/16 06:08:27 gomor $
+# $Id: Countrycode.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
 #
 # lookup::countrycode Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a6e30d37450c $',
+      revision => '$Revision: 508610fe2b1a $',
       tags => [ qw(unstable lookup iana countrycode cc) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -62,7 +62,7 @@ sub update {
    my $uri = 'http://www.iana.org/domains/root/db';
 
    my $get = $self->get($uri) or return $self->log->error("update: get failed");
-   my $html = $get->{body};
+   my $html = $get->{content};
 
    # <tr class="iana-group-1 iana-type-2">
    #   <td><span class="domain tld"><a href="/domains/root/db/abogado.html">.abogado</a></span></td>
