@@ -1,5 +1,5 @@
 #
-# $Id: Iplocation.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Iplocation.pm,v 0a43e0ac3f36 2015/10/12 19:19:10 gomor $
 #
 # lookup::iplocation Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable location ipv4 ipv6 ip geo geolocation) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: 0a43e0ac3f36 $',
+      tags => [ qw(unstable lookup location ipv4 ipv6 ip) ],
       attributes => {
          datadir => [ qw(datadir) ],
       },
@@ -28,8 +26,11 @@ sub brik_properties {
       },
       require_modules => {
          'Geo::IP' => [ ],
-         'Metabrik::Client::Www' => [ ],
-         'Metabrik::File::Compress' => [ ],
+         'LWP::Simple' => [ ],
+         'File::Copy' => [ ],
+         'File::Spec' => [ ],
+         'PerlIO' => [ ],
+         'PerlIO::gzip' => [ ],
       },
    };
 }
@@ -37,30 +38,52 @@ sub brik_properties {
 sub update {
    my $self = shift;
 
-   my $datadir = $self->datadir;
+   eval('use LWP::Simple qw(mirror RC_NOT_MODIFIED RC_OK $ua);');
+   eval('use File::Copy qw(mv);');
 
-   my $dl_path = 'http://geolite.maxmind.com/download/geoip/database/';
+   my $download_dir = $self->datadir;
+   my $dest_dir = $self->datadir;
 
    my %mirror = (
-      'GeoIP.dat.gz' => 'GeoLiteCountry/GeoIP.dat.gz',
-      'GeoIPCity.dat.gz' => 'GeoLiteCity.dat.gz',
-      'GeoIPv6.dat.gz' => 'GeoIPv6.dat.gz',
+      'GeoIP.dat.gz'      => 'GeoLiteCountry/GeoIP.dat.gz',
+      'GeoIPCity.dat.gz'  => 'GeoLiteCity.dat.gz',
+      'GeoIPv6.dat.gz'    => 'GeoIPv6.dat.gz',
       'GeoIPASNum.dat.gz' => 'asnum/GeoIPASNum.dat.gz'
    );
 
-   my $cw = Metabrik::Client::Www->new_from_brik_init($self) or return;
-   $cw->user_agent("Metabrik-MaxMind-geolite-mirror/1.01");
-   $cw->datadir($datadir);
-
-   my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
-   $fc->datadir($datadir);
+   $LWP::Simple::ua->agent("Metabrik-MaxMind-geolite-mirror/1.00");
+   my $dl_path = 'http://geolite.maxmind.com/download/geoip/database/';
 
+   chdir($download_dir)
+      or return $self->log->error("update: unable to chdir to [$download_dir]: $!");
    for my $f (keys %mirror) {
-      my $files = $cw->mirror($dl_path.$mirror{$f}, $f) or next;
-      for my $file (@$files) {
-         (my $outfile = $file) =~ s/\.gz$//;
-         $self->log->verbose("update: uncompressing to [$outfile]");
-         $fc->uncompress($datadir.'/'.$file, $outfile) or next;
+      my $rc = mirror($dl_path.$mirror{$f}, $f);
+      if ($rc == LWP::Simple::RC_NOT_MODIFIED()) {
+         next;
+      }
+      if ($rc == LWP::Simple::RC_OK()) {
+         (my $outfile = $f) =~ s/\.gz$//;
+         my $r = open(my $in, '<:gzip', $f);
+         if (! defined($r)) {
+            $self->log->error("update: unable to unzip file [$f]: $!");
+            next;
+         }
+         $r = open(my $out, '>', $outfile);
+         if (! defined($r)) {
+            $self->log->error("update: unable to open file [$outfile]: $!");
+            next;
+         }
+         while (<$in>) {
+            print $out $_
+               or $self->log->error("update: unable to write to file [$outfile]: $!");
+         }
+         $r = mv($outfile, File::Spec->catfile($dest_dir, $outfile));
+         if (! defined($r)) {
+            $self->log->error("update: unable to move file [$outfile] to [$dest_dir]: $!");
+            next;
+         }
+
+         $self->log->info("update: file [$outfile] created or updated in [$dest_dir]");
       }
    }
 
@@ -71,7 +94,9 @@ sub from_ipv4 {
    my $self = shift;
    my ($ipv4) = @_;
 
-   $self->brik_help_run_undef_arg('from_ipv4', $ipv4) or return;
+   if (! defined($ipv4)) {
+      return $self->log->error($self->brik_help_run('from_ipv4'));
+   }
 
    my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
       or return $self->log->error("from_ipv4: unable to open GeoIPCity.dat");
@@ -86,7 +111,9 @@ sub from_ipv6 {
    my $self = shift;
    my ($ipv6) = @_;
 
-   $self->brik_help_run_undef_arg('from_ipv6', $ipv6) or return;
+   if (! defined($ipv6)) {
+      return $self->log->error($self->brik_help_run('from_ipv6'));
+   }
 
    my $gi = Geo::IP->open($self->datadir.'/GeoIPv6.dat')
       or return $self->log->error("from_ipv6: unable to open GeoIPv6.dat");
@@ -101,7 +128,9 @@ sub from_ip {
    my $self = shift;
    my ($ip) = @_;
 
-   $self->brik_help_run_undef_arg('from_ip', $ip) or return;
+   if (! defined($ip)) {
+      return $self->log->error($self->brik_help_run('from_ip'));
+   }
 
    my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
    if ($na->is_ipv4($ip)) {
@@ -120,7 +149,9 @@ sub subnet4 {
    my $self = shift;
    my ($ipv4_address) = @_;
 
-   $self->brik_help_run_undef_arg('subnet4', $ipv4_address) or return;
+   if (! defined($ipv4_address)) {
+      return $self->log->error($self->brik_help_run('subnet4'));
+   }
 
    my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
       or return $self->log->error("subnet4: unable to open GeoIPCity.dat");
@@ -134,7 +165,9 @@ sub organization_name {
    my $self = shift;
    my ($ip_address) = @_;
 
-   $self->brik_help_run_undef_arg('organization_name', $ip_address) or return;
+   if (! defined($ip_address)) {
+      return $self->log->error($self->brik_help_run('organization_name'));
+   }
   
    my $gi = Geo::IP->open($self->datadir.'/GeoIPCity.dat', Geo::IP::GEOIP_STANDARD())
       or return $self->log->error("organization_name: unable to open GeoIPCity.dat");
@@ -154,7 +187,7 @@ Metabrik::Lookup::Iplocation - lookup::iplocation Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
