@@ -1,5 +1,5 @@
 #
-# $Id: Protocol.pm,v f0806c23ff74 2015/01/25 18:03:03 gomor $
+# $Id: Protocol.pm,v e9efd64d88ce 2015/02/26 06:10:35 gomor $
 #
 # lookup::protocol Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Csv);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f0806c23ff74 $',
+      revision => '$Revision: e9efd64d88ce $',
       tags => [ qw(unstable lookup protocol iana) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -103,7 +103,7 @@ sub from_dec {
    }
 
    # No match
-   return;
+   return 'unknown';
 }
 
 sub from_hex {
