@@ -1,5 +1,5 @@
 #
-# $Id: Device.pm,v 39f1159c4a8c 2015/02/17 06:45:33 gomor $
+# $Id: Device.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
 #
 # network::device Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 39f1159c4a8c $',
+      revision => '$Revision: 508610fe2b1a $',
       tags => [ qw(unstable network device interface) ],
       attributes => {
          'enable_warnings' => [ qw(0|1) ],
@@ -188,7 +188,7 @@ sub internet_address {
    my $get = $cw->get($url)
       or return $self->log->error("internet_address: get failed");
 
-   my $html = $get->{body};
+   my $html = $get->{content};
 
    my ($ip) = $html =~ /(\d+\.\d+\.\d+\.\d+)/;
 
