@@ -1,5 +1,5 @@
 #
-# $Id: Http.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Http.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # network::http Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Tcp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable http) ],
       attributes => {
          host_header => [ qw(host_header) ],
@@ -49,7 +49,7 @@ sub probe {
    $self->disconnect;
 
    if (length($response)) {
-      my $parse = Metabrik::String::Parse->new;
+      my $parse = Metabrik::String::Parse->new_from_brik_init($self) or return;
       return $parse->to_array($response);
    }
 
