@@ -1,5 +1,5 @@
 #
-# $Id: Nikto.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Nikto.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # network::nikto Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable network security scanner nikto) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -57,7 +57,7 @@ sub start {
       return $self->log->error($self->brik_help_set('uri'));
    }
 
-   my $target = Metabrik::String::Uri->new_from_brik($self);
+   my $target = Metabrik::String::Uri->new_from_brik($self) or return;
    my $p = $target->parse($uri);
 
    my $host = $p->{host};
