@@ -1,5 +1,5 @@
 #
-# $Id: Tor.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Tor.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
 #
 # network::tor Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 508610fe2b1a $',
       tags => [ qw(unstable tor exitnodes) ],
       attributes => {
          uri => [ qw(uri) ],
@@ -37,7 +37,7 @@ sub exit_nodes_list {
 
    my $get = $self->get or return $self->log->error('exit_nodes_list: get failed');
 
-   my $ip_list = $get->{body};
+   my $ip_list = $get->{content};
 
    my @ip_list = split(/\n/, $ip_list);
    my %ip_list = ();
