@@ -1,5 +1,5 @@
 #
-# $Id: Write.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Write.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # network::write Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable network write ethernet ip raw socket) ],
       attributes => {
          device => [ qw(device) ],
@@ -57,6 +57,10 @@ sub open {
    my $self = shift;
    my ($layer, $arg2, $arg3) = @_;
 
+   if ($< != 0) {
+      return $self->log->error("open: must be root to run");
+   }
+
    $layer ||= $self->layer;
 
    my $family = $self->family eq 'ipv6'
@@ -202,7 +206,7 @@ sub fnsend_reply {
       $target = $ip->dst;
    }
 
-   my $read = Metabrik::Network::Read->new_from_brik($self);
+   my $read = Metabrik::Network::Read->new_from_brik($self) or return;
    $read->layer(2);
    $read->device($self->device);
    $read->rtimeout($self->global->rtimeout);
