@@ -1,5 +1,5 @@
 #
-# $Id: Json.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Json.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
 #
 # string::json Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 508610fe2b1a $',
       tags => [ qw(unstable encode decode json) ],
       commands => {
          encode => [ qw($data_list|$data_hash) ],
@@ -35,7 +35,14 @@ sub encode {
       return $self->log->error("encode: you need to give data as an ARRAYREF or HASHREF");
    }
 
-   my $encoded = JSON::XS::encode_json($data);
+   my $encoded = '';
+   eval {
+      $encoded = JSON::XS::encode_json($data);
+   };
+   if ($@) {
+      chomp($@);
+      return $self->log->erro("decode: unable to decode JSON: $@");
+   }
 
    return $encoded;
 }
@@ -48,7 +55,14 @@ sub decode {
       return $self->log->error($self->brik_help_run('decode'));
    }
 
-   my $decoded = JSON::XS::decode_json($data);
+   my $decoded = '';
+   eval {
+      $decoded = JSON::XS::decode_json($data);
+   };
+   if ($@) {
+      chomp($@);
+      return $self->log->erro("decode: unable to decode JSON: $@");
+   }
 
    return $decoded;
 }
